Backends Module
===============

This module contains the various video processing backends.

Backend Manager
---------------

.. automodule:: fmusvid.backends.manager
   :members:
   :undoc-members:

Base Backend
------------

.. autoclass:: fmusvid.backends.backend.Backend
   :members:
   :undoc-members:
   :show-inheritance:

FFmpeg Backend
--------------

.. automodule:: fmusvid.backends.ffmpeg
   :members:
   :undoc-members:

.. automodule:: fmusvid.backends.ffmpeg.core
   :members:
   :undoc-members:

.. automodule:: fmusvid.backends.ffmpeg.filters
   :members:
   :undoc-members:

.. automodule:: fmusvid.backends.ffmpeg.conversion
   :members:
   :undoc-members:

.. automodule:: fmusvid.backends.ffmpeg.overlay
   :members:
   :undoc-members:

.. automodule:: fmusvid.backends.ffmpeg.subtitle
   :members:
   :undoc-members:

.. automodule:: fmusvid.backends.ffmpeg.audio
   :members:
   :undoc-members:

VLC Backend
-----------

.. automodule:: fmusvid.backends.vlc
   :members:
   :undoc-members:

MoviePy Backend
---------------

.. automodule:: fmusvid.backends.moviepy
   :members:
   :undoc-members:

PyAV Backend
------------

.. automodule:: fmusvid.backends.pyav
   :members:
   :undoc-members:

GStreamer Backend
-----------------

.. automodule:: fmusvid.backends.gstreamer
   :members:
   :undoc-members:
